==> nextcloud-23.0.8.tgz: nextcloud/apps/activity/l10n/zh_HK.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "請按【⌘-C】以複製。",
    "Press Ctrl-C to copy." : "請按【Ctrl-C】以複製。",
    "{name} (invisible)" : "{name}（隱藏）",
    "{name} (restricted)" : "{name}（受限）",
    "Home" : "主頁",
    "in {path}" : "在 {path}",
    "This stream will show events like additions, changes & shares" : "這裡將顯示檔案的新增、更動、分享等系統事件",
    "There are no events for this filter" : "在此篩選器下沒有系統事件",
    "Today" : "今日",
    "Yesterday" : "昨日",
    "Open {filename}" : "打開  {filename}",
    "Personal activity feed for %s" : "%s 的個人系統事件摘要",
    "Your feed URL is invalid" : "您的 Feed URL 是無效的",
    "Your settings have been updated." : "您的設定已更新。",
    "Settings have been updated." : "設定已更新。",
    "Recent activity" : "近期活動",
    "Daily activity summary for %s" : "%s 的每日系統事件摘要",
    "_and %n more _::_and %n more _" : ["以及其餘 %n 項"],
    "All activities" : "所有系統事件",
    "By others" : "其他人的活動",
    "By you" : "您的活動",
    "Activity at %s" : "%s 上的活動",
    "Hello %s" : "%s 您好",
    "Hello %s," : "%s 您好，",
    "There was some activity at %s" : "%s 有一些系統事件",
    "Mail" : "電子郵件",
    "Push" : "推送",
    "Activity" : "系統事件簿",
    "Notifications" : "通告",
    "This application enables users to view a log of activities about them or about files." : "此應用程式允許用戶在 Nextcloud 中查看與其檔案相關的操作。",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "此應用程式讓用戶能夠在 Nextcloud 中查看與其檔案相關的操作。\n\t\t啟用後，用戶將在其選單中看到一個「系統事件」新圖示。\n\t\t點選後，將顯示一個新頁面，以供用戶追踪與檔案相關的系統事件﹣包含新增檔案、已刪除檔案、移動、重新命名、更新和分享系統事件。\n\t\t用戶可以在其個人選單中配置其各自的系統事件設定。\n\t\t此設定了想要記錄的系統事件類型，以及用戶是否可看到自己的系統事件，\n\t\t並是否僅為線上提供，以及是否定期收到電子郵件摘要。\n\t\t系統事件使用手冊中提供更多訊息。",
    "No activity yet" : "尚無系統事件",
    "Unable to load the activity list" : "無法載入活動紀錄清單",
    "Activities" : "活動",
    "No activities" : "沒有動態",
    "Activity feed" : "系統事件摘要",
    "Enable notification emails" : "啟用電郵通告",
    "Default settings" : "默認設定",
    "Configure the default notification settings." : "設定默認的通知設定。",
    "You need to set up your email address before you can receive notification emails." : "您必須先設定電郵地址，才能接收通知。",
    "Send activity emails:" : "傳送有關系統事件的電郵：",
    "As soon as possible" : "盡快",
    "Hourly" : "每小時",
    "Daily" : "每日",
    "Weekly" : "每星期",
    "Choose for which activities you want to get an email or push notification." : "選擇您要獲取電子郵件或推送通知的系統事件。",
    "Choose for which activities you want to get a push notification." : "選擇您要獲取推送通知的系統事件。",
    "Daily activity summary" : "每日系統事件摘要",
    "Send daily activity summary in the morning" : "於早上傳送每日系統事件摘要",
    "Activity settings" : "活動紀錄設定",
    "Enable RSS feed" : "啟用 RSS 摘要",
    "RSS feed" : "RSS 摘要",
    "Personal notification settings" : "個人通告設定",
    "No more events to load" : "已載入所有事件",
    "Activity notification for %s" : "%s 的系統事件通告",
    "Send notification emails:" : "透過電郵接收通知：",
    "Settings" : "設定",
    "Personal Activity Settings" : "個人活動設定",
    "activities" : "活動"
},
"nplurals=1; plural=0;");

==> nextcloud-23.0.12p0.tgz: nextcloud/apps/activity/l10n/zh_HK.js <==
OC.L10N.register(
    "activity",
    {
    "Copied!" : "已複製！",
    "Not supported!" : "不支援！",
    "Press ⌘-C to copy." : "請按【⌘-C】以複製。",
    "Press Ctrl-C to copy." : "請按【Ctrl-C】以複製。",
    "{name} (invisible)" : "{name}（隱藏）",
    "{name} (restricted)" : "{name}（受限）",
    "Home" : "主頁",
    "in {path}" : "在 {path}",
    "This stream will show events like additions, changes & shares" : "這裡將顯示檔案的新增、更新、分享等系統事件",
    "There are no events for this filter" : "在此篩選器下沒有系統事件",
    "Today" : "今日",
    "Yesterday" : "昨日",
    "Open {filename}" : "打開  {filename}",
    "Personal activity feed for %s" : "%s 的個人系統事件摘要",
    "Your feed URL is invalid" : "您的 Feed URL 是無效的",
    "Your settings have been updated." : "您的設定已更新。",
    "Settings have been updated." : "設定已更新。",
    "Recent activity" : "近期活動",
    "More activities" : "更多活動",
    "Daily activity summary for %s" : "%s 的每日系統事件摘要",
    "_and %n more _::_and %n more _" : ["以及其餘 %n 項"],
    "All activities" : "所有系統事件",
    "By others" : "其他人的活動",
    "By you" : "您的活動",
    "Activity at %s" : "%s 上的活動",
    "Hello %s" : "%s 您好",
    "Hello %s," : "%s 您好，",
    "There was some activity at %s" : "%s 有一些系統事件",
    "Mail" : "電子郵件",
    "Push" : "推送",
    "Activity" : "系統事件簿",
    "Notifications" : "通告",
    "This application enables people to view a log of activities about them, their files or other data." : "此應用程式使人們能夠查看有關他們、他們的檔案或其他數據的活動記錄。",
    "This app allows people to see actions related to their files and data in Nextcloud.\n\t\tEach person can configure their individual activity settings in the personal settings,\n\t\tto choose which activity should be pushed to mobile phones, sent via email\n\t\tor whether a daily summary is sent each morning.\n\t\tMore information is available in the Activity documentation." : "這個應用程式允許人們在 Nextcloud 中查看與其檔案和數據相關的操作。\n\t\t每個人都可以在個人設置中配置自己的個人活動紀錄設置，\n\t\t選擇應該推送到手機或通過電子郵件發送的活動\n\t\t或是否每天早上發送每日摘要。\n\t\t可在活動紀錄說明書中找到更多資訊。",
    "Activity notification configuration" : "活動通知配置",
    "Send email" : "傳送電郵",
    "Send push notification" : "傳送推送通告",
    "You need to set up your email address before you can receive notification emails." : "您必須先設定電郵地址，才能接收通知。",
    "Send activity emails" : "傳送有關系統活動的電郵",
    "As soon as possible" : "盡快",
    "Hourly" : "每小時",
    "Daily" : "每日",
    "Weekly" : "每星期",
    "No activity yet" : "尚無系統事件",
    "Unable to load the activity list" : "無法載入活動紀錄清單",
    "Notification" : "通告",
    "Enable notification emails" : "啟用電郵通告",
    "Choose for which activities you want to get an email or push notification." : "選擇您要獲取電子郵件或推送通知的系統事件。",
    "Choose for which activities you want to get a push notification." : "選擇您要獲取推送通知的系統事件。",
    "Daily activity summary" : "每日系統事件摘要",
    "Send daily activity summary in the morning" : "於早上傳送每日系統事件摘要",
    "Activities" : "活動",
    "No activities" : "沒有動態",
    "Default settings" : "默認設定",
    "Configure the default notification settings for new accounts." : "為新賬戶配置默認通知設置。",
    "Unable to save the settings" : "無法保存設定",
    "Activity feed" : "系統事件摘要",
    "Activity settings" : "活動紀錄設定",
    "Enable RSS feed" : "啟用 RSS 摘要",
    "RSS feed" : "RSS 摘要",
    "Personal notification settings" : "個人通告設定",
    "No more events to load" : "已載入所有事件",
    "Activity notification for %s" : "%s 的系統事件通告",
    "This application enables users to view a log of activities about them or about files." : "此應用程式允許用戶在 Nextcloud 中查看與其檔案相關的操作。",
    "This application enables users to view actions related to their files in Nextcloud.\n\t\tOnce enabled, users will see a new icon “Activity” in their apps menu.\n\t\tWhen clicked, a new page appears for users to track the activity related to files – from new files, to deleted files, move, rename, updates and shared activity.\n\t\tThe user can configure their individual activity settings in their personal menu.\n\t\tThis sets the type of activity to record, as well as whether to the user sees their own activities,\n\t\twhether these are only available online, and whether they get an email digest on a regular basis.\n\t\tMore information is available in the Activity documentation." : "此應用程式讓用戶能夠在 Nextcloud 中查看與其檔案相關的操作。\n\t\t啟用後，用戶將在其選單中看到一個「系統事件」新圖示。\n\t\t點選後，將顯示一個新頁面，以供用戶追踪與檔案相關的系統事件﹣包含新增檔案、已刪除檔案、移動、重新命名、更新和分享系統事件。\n\t\t用戶可以在其個人選單中配置其各自的系統事件設定。\n\t\t此設定了想要記錄的系統事件類型，以及用戶是否可看到自己的系統事件，\n\t\t並是否僅為線上提供，以及是否定期收到電子郵件摘要。\n\t\t系統事件使用手冊中提供更多訊息。",
    "activities" : "活動",
    "Configure the default notification settings." : "設定默認的通知設定。",
    "Send activity emails:" : "傳送有關系統事件的電郵：",
    "Settings" : "設定",
    "Configure the default notification settings for new users." : "為新用戶配置默認通知設置。"
},
"nplurals=1; plural=0;");
